package javax.swing.plaf.nimbus;

import javax.swing.plaf.ColorUIResource;
import java.awt.Font;
import javax.swing.plaf.synth.ColorType;
import javax.swing.Painter;
import java.util.Iterator;
import java.util.Map;
import java.util.Collections;
import java.awt.Insets;
import java.util.HashMap;
import java.util.ArrayList;
import java.util.TreeMap;
import javax.swing.UIDefaults;
import javax.swing.UIManager;
import javax.swing.plaf.synth.SynthContext;
import javax.swing.JComponent;
import java.lang.ref.WeakReference;
import javax.swing.plaf.synth.SynthPainter;
import java.util.Comparator;
import java.awt.Color;
import javax.swing.plaf.synth.SynthStyle;

public final class NimbusStyle extends SynthStyle
{
    public static final String LARGE_KEY = "large";
    public static final String SMALL_KEY = "small";
    public static final String MINI_KEY = "mini";
    public static final double LARGE_SCALE = 1.15;
    public static final double SMALL_SCALE = 0.857;
    public static final double MINI_SCALE = 0.714;
    private static final Object NULL;
    private static final Color DEFAULT_COLOR;
    private static final Comparator<NimbusStyle.RuntimeState> STATE_COMPARATOR;
    private String prefix;
    private SynthPainter painter;
    private NimbusStyle.Values values;
    private NimbusStyle.CacheKey tmpKey;
    private WeakReference<JComponent> component;
    
    NimbusStyle(String prefix, JComponent referent) {
        this.tmpKey = new NimbusStyle.CacheKey("", 0);
        if (referent != null) {
            this.component = new WeakReference(referent);
        }
        this.prefix = prefix;
        this.painter = new SynthPainterImpl(this);
    }
    
    @Override
    public void installDefaults(SynthContext context) {
        this.validate();
        super.installDefaults(context);
    }
    
    private void validate() {
        if (this.values != null) {
            return;
        }
        this.values = new NimbusStyle.Values();
        Map<String, Object> defaultsForPrefix = ((NimbusLookAndFeel)UIManager.getLookAndFeel()).getDefaultsForPrefix(this.prefix);
        if (this.component != null) {
            Object clientProperty = ((JComponent)this.component.get()).getClientProperty("Nimbus.Overrides");
            if ((clientProperty instanceof UIDefaults)) {
                Object clientProperty2 = ((JComponent)this.component.get()).getClientProperty("Nimbus.Overrides.InheritDefaults");
                int n = !(clientProperty2 instanceof Boolean) || (boolean)clientProperty2;
                UIDefaults uiDefaults = (UIDefaults)clientProperty;
                TreeMap<String, Object> treeMap = new TreeMap();
                for (Object next : uiDefaults.keySet()) {
                    if ((next instanceof String)) {
                        String s = (String)next;
                        if (s.startsWith(this.prefix)) {
                            treeMap.put(s, uiDefaults.get(s));
                        }
                        else {
                            continue;
                        }
                    }
                    else {
                        continue;
                    }
                }
                if (!(n == 0)) {
                    defaultsForPrefix.putAll(treeMap);
                }
                else {
                    defaultsForPrefix = treeMap;
                }
            }
        }
        ArrayList o = new ArrayList();
        HashMap o2 = new HashMap();
        ArrayList list = new ArrayList();
        String s2 = (String)defaultsForPrefix.get(this.prefix + ".States");
        if (s2 != null) {
            String[] split = s2.split(",");
            for (int i = 0; i < split.length; ++i) {
                split[i] = split[i].trim();
                if (!State.isStandardStateName(split[i])) {
                    State<Object> state = (State)defaultsForPrefix.get(this.prefix + "." + split[i]);
                    if (state != null) {
                        o.add(state);
                    }
                }
                else {
                    o.add(State.getStandardState(split[i]));
                }
            }
            if (o.size() > 0) {
                this.values.stateTypes = (State[])o.toArray(new State[o.size()]);
            }
            int j = 1;
            for (Iterator iterator2 = o.iterator(); iterator2.hasNext(); j <<= 1) {
                o2.put(((State)iterator2.next()).getName(), Integer.valueOf(j));
            }
        }
        else {
            o.add(State.Enabled);
            o.add(State.MouseOver);
            o.add(State.Pressed);
            o.add(State.Disabled);
            o.add(State.Focused);
            o.add(State.Selected);
            o.add(State.Default);
            o2.put("Enabled", Integer.valueOf(1));
            o2.put("MouseOver", Integer.valueOf(2));
            o2.put("Pressed", Integer.valueOf(4));
            o2.put("Disabled", Integer.valueOf(8));
            o2.put("Focused", Integer.valueOf(256));
            o2.put("Selected", Integer.valueOf(512));
            o2.put("Default", Integer.valueOf(1024));
        }
        for (String s3 : defaultsForPrefix.keySet()) {
            String substring = s3.substring(this.prefix.length());
            if (substring.indexOf(34) != -1) {
                continue;
            }
            if (substring.indexOf(58) != -1) {
                continue;
            }
            String key = substring.substring(1);
            String substring2 = null;
            int index = key.indexOf(93);
            if (index < 0) {
            }
            else {
                substring2 = key.substring(0, index);
                key = key.substring(index + 2);
            }
            if (substring2 == null) {
                if ("contentMargins".equals(key)) {
                    this.values.contentMargins = (Insets)defaultsForPrefix.get(s3);
                }
                else {
                    if ("States".equals(key)) {
                        continue;
                    }
                    this.values.defaults.put(key, defaultsForPrefix.get(s3));
                }
            }
            else {
                boolean n2 = false;
                int n3 = 0;
                String[] split2 = substring2.split("\\+");
                int length = split2.length;
                int k = 0;
                while (k < length) {
                    String s4 = split2[k];
                    if (o2.containsKey(s4)) {
                        n3 |= (int)o2.get(s4);
                        ++k;
                    }
                    else {
                        n2 = true;
                        break;
                    }
                }
                if (!(n2 == 0)) {
                    continue;
                }
                Object o3 = null;
                for (NimbusStyle.RuntimeState runtimeState : list) {
                    if (runtimeState.state == n3) {
                        o3 = runtimeState;
                        break;
                    }
                    continue;
                }
                if (o3 == null) {
                    o3 = new NimbusStyle.RuntimeState(n3, substring2);
                    list.add(o3);
                }
                if ("backgroundPainter".equals(key)) {
                    o3.backgroundPainter = this.getPainter(defaultsForPrefix, s3);
                }
                else if ("foregroundPainter".equals(key)) {
                    o3.foregroundPainter = this.getPainter(defaultsForPrefix, s3);
                }
                else if ("borderPainter".equals(key)) {
                    o3.borderPainter = this.getPainter(defaultsForPrefix, s3);
                }
                else {
                    o3.defaults.put(key, defaultsForPrefix.get(s3));
                }
            }
        }
        Collections.sort(list, NimbusStyle.STATE_COMPARATOR);
        this.values.states = (NimbusStyle.RuntimeState[])list.toArray(new NimbusStyle.RuntimeState[list.size()]);
        return;
    }
    
    private Painter getPainter(Map<String, Object> map, String s) {
        Object o = map.get(s);
        if ((o instanceof UIDefaults.LazyValue)) {
            o = ((UIDefaults.LazyValue)o).createValue(UIManager.getDefaults());
        }
        return (o instanceof Painter) ? ((Painter)o) : null;
    }
    
    @Override
    public Insets getInsets(SynthContext synthContext, Insets insets) {
        if (insets == null) {
            insets = new Insets(0, 0, 0, 0);
        }
        NimbusStyle.Values values = this.getValues(synthContext);
        if (values.contentMargins == null) {
            Insets insets14 = insets;
            Insets insets15 = insets;
            Insets insets16 = insets;
            Insets insets17 = insets;
            int n = 0;
            insets17.right = n;
            insets16.left = n;
            insets15.top = n;
            insets14.bottom = n;
            return insets;
        }
        insets.bottom = values.contentMargins.bottom;
        insets.top = values.contentMargins.top;
        insets.left = values.contentMargins.left;
        insets.right = values.contentMargins.right;
        String anObject = (String)synthContext.getComponent().getClientProperty("JComponent.sizeVariant");
        if (anObject != null) {
            if ("large".equals(anObject)) {
                Insets insets10 = insets;
                insets10.bottom = (int)((double)insets10.bottom * 1.15);
                Insets insets11 = insets;
                insets11.top = (int)((double)insets11.top * 1.15);
                Insets insets12 = insets;
                insets12.left = (int)((double)insets12.left * 1.15);
                Insets insets13 = insets;
                insets13.right = (int)((double)insets13.right * 1.15);
            }
            else if ("small".equals(anObject)) {
                Insets insets6 = insets;
                insets6.bottom = (int)((double)insets6.bottom * 0.857);
                Insets insets7 = insets;
                insets7.top = (int)((double)insets7.top * 0.857);
                Insets insets8 = insets;
                insets8.left = (int)((double)insets8.left * 0.857);
                Insets insets9 = insets;
                insets9.right = (int)((double)insets9.right * 0.857);
            }
            else if ("mini".equals(anObject)) {
                Insets insets2 = insets;
                insets2.bottom = (int)((double)insets2.bottom * 0.714);
                Insets insets3 = insets;
                insets3.top = (int)((double)insets3.top * 0.714);
                Insets insets4 = insets;
                insets4.left = (int)((double)insets4.left * 0.714);
                Insets insets5 = insets;
                insets5.right = (int)((double)insets5.right * 0.714);
            }
        }
        return insets;
    }
    
    @Override
    protected Color getColorForState(SynthContext synthContext, ColorType colorType) {
        String string;
        if (colorType == ColorType.BACKGROUND) {
            string = "background";
        }
        else if (colorType == ColorType.FOREGROUND) {
            string = "textForeground";
        }
        else if (colorType == ColorType.TEXT_BACKGROUND) {
            string = "textBackground";
        }
        else if (colorType == ColorType.TEXT_FOREGROUND) {
            string = "textForeground";
        }
        else if (colorType == ColorType.FOCUS) {
            string = "focus";
        }
        else if (colorType != null) {
            string = colorType.toString();
        }
        else {
            return NimbusStyle.DEFAULT_COLOR;
        }
        Color default_COLOR = (Color)this.get(synthContext, string);
        if (default_COLOR == null) {
            default_COLOR = NimbusStyle.DEFAULT_COLOR;
            return default_COLOR;
        }
        return default_COLOR;
    }
    
    @Override
    protected Font getFontForState(SynthContext synthContext) {
        Font font = (Font)this.get(synthContext, "font");
        if (font == null) {
            font = UIManager.getFont("defaultFont");
        }
        String anObject = (String)synthContext.getComponent().getClientProperty("JComponent.sizeVariant");
        if (anObject != null) {
            if ("large".equals(anObject)) {
                font = font.deriveFont((float)Math.round((double)font.getSize2D() * 1.15));
            }
            else if ("small".equals(anObject)) {
                font = font.deriveFont((float)Math.round((double)font.getSize2D() * 0.857));
            }
            else if ("mini".equals(anObject)) {
                font = font.deriveFont((float)Math.round((double)font.getSize2D() * 0.714));
            }
        }
        return font;
    }
    
    @Override
    public SynthPainter getPainter(SynthContext synthContext) {
        return this.painter;
    }
    
    @Override
    public boolean isOpaque(SynthContext synthContext) {
        if ("Table.cellRenderer".equals(synthContext.getComponent().getName())) {
            return true;
        }
        Boolean b = (Boolean)this.get(synthContext, "opaque");
        return b != null && (boolean)b;
    }
    
    @Override
    public Object get(SynthContext context, Object o) {
        NimbusStyle.Values values = this.getValues(context);
        String string = o.toString();
        String substring = string.substring(string.indexOf(".") + 1);
        int extendedState = this.getExtendedState(context, values);
        this.tmpKey.init(substring, extendedState);
        Object o2 = values.cache.get(this.tmpKey);
        if (o2 == null) {
            NimbusStyle.RuntimeState nextState;
            for (int[] array = { -1 }; o2 == null && (nextState = this.getNextState(values.states, array, extendedState)) != null; o2 = nextState.defaults.get(substring)) {}
            if (o2 == null && values.defaults != null) {
                o2 = values.defaults.get(substring);
            }
            if (o2 == null) {
                o2 = UIManager.get(string);
            }
            if (o2 == null && substring.equals("focusInputMap")) {
                o2 = super.get(context, string);
            }
            values.cache.put(new NimbusStyle.CacheKey(substring, extendedState), (o2 == null) ? NimbusStyle.NULL : o2);
        }
        return (o2 == NimbusStyle.NULL) ? null : o2;
    }
    
    public Painter getBackgroundPainter(SynthContext synthContext) {
        NimbusStyle.Values values = this.getValues(synthContext);
        int extendedState = this.getExtendedState(synthContext, values);
        this.tmpKey.init("backgroundPainter$$instance", extendedState);
        Painter<Object> backgroundPainter = (Painter)values.cache.get(this.tmpKey);
        if (backgroundPainter != null) {
            return backgroundPainter;
        }
        NimbusStyle.RuntimeState nextState;
        while ((nextState = this.getNextState(values.states, new int[] { -1 }, extendedState)) != null) {
            if (nextState.backgroundPainter == null) {
                continue;
            }
            backgroundPainter = nextState.backgroundPainter;
            break;
        }
        if (backgroundPainter == null) {
            backgroundPainter = (Painter)this.get(synthContext, "backgroundPainter");
        }
        if (backgroundPainter != null) {
            values.cache.put(new NimbusStyle.CacheKey("backgroundPainter$$instance", extendedState), backgroundPainter);
            return backgroundPainter;
        }
        return backgroundPainter;
    }
    
    public Painter getForegroundPainter(SynthContext synthContext) {
        NimbusStyle.Values values = this.getValues(synthContext);
        int extendedState = this.getExtendedState(synthContext, values);
        this.tmpKey.init("foregroundPainter$$instance", extendedState);
        Painter<Object> foregroundPainter = (Painter)values.cache.get(this.tmpKey);
        if (foregroundPainter != null) {
            return foregroundPainter;
        }
        NimbusStyle.RuntimeState nextState;
        while ((nextState = this.getNextState(values.states, new int[] { -1 }, extendedState)) != null) {
            if (nextState.foregroundPainter == null) {
                continue;
            }
            foregroundPainter = nextState.foregroundPainter;
            break;
        }
        if (foregroundPainter == null) {
            foregroundPainter = (Painter)this.get(synthContext, "foregroundPainter");
        }
        if (foregroundPainter != null) {
            values.cache.put(new NimbusStyle.CacheKey("foregroundPainter$$instance", extendedState), foregroundPainter);
            return foregroundPainter;
        }
        return foregroundPainter;
    }
    
    public Painter getBorderPainter(SynthContext synthContext) {
        NimbusStyle.Values values = this.getValues(synthContext);
        int extendedState = this.getExtendedState(synthContext, values);
        this.tmpKey.init("borderPainter$$instance", extendedState);
        Painter<Object> borderPainter = (Painter)values.cache.get(this.tmpKey);
        if (borderPainter != null) {
            return borderPainter;
        }
        NimbusStyle.RuntimeState nextState;
        while ((nextState = this.getNextState(values.states, new int[] { -1 }, extendedState)) != null) {
            if (nextState.borderPainter == null) {
                continue;
            }
            borderPainter = nextState.borderPainter;
            break;
        }
        if (borderPainter == null) {
            borderPainter = (Painter)this.get(synthContext, "borderPainter");
        }
        if (borderPainter != null) {
            values.cache.put(new NimbusStyle.CacheKey("borderPainter$$instance", extendedState), borderPainter);
            return borderPainter;
        }
        return borderPainter;
    }
    
    private NimbusStyle.Values getValues(SynthContext synthContext) {
        this.validate();
        return this.values;
    }
    
    private boolean contains(String[] array, String s) {
        assert s != null;
        int i = 0;
        while (i < array.length) {
            if (s.equals(array[i])) {
                return true;
            }
            ++i;
        }
        return false;
    }
    
    private int getExtendedState(SynthContext synthContext, NimbusStyle.Values values) {
        JComponent component = synthContext.getComponent();
        int n = 0;
        int n2 = 1;
        Object clientProperty = component.getClientProperty("Nimbus.State");
        if (clientProperty != null) {
            String[] split = clientProperty.toString().split("\\+");
            if (values.stateTypes == null) {
                for (int length3 = split.length, k = 0; k < length3; ++k) {
                    State.StandardState standardState = State.getStandardState(split[k]);
                    if (standardState != null) {
                        n |= standardState.getState();
                    }
                }
            }
            else {
                State[] stateTypes2 = values.stateTypes;
                for (int length2 = stateTypes2.length, j = 0; j < length2; n2 <<= 1, ++j) {
                    if (this.contains(split, stateTypes2[j].getName())) {
                        n |= n2;
                    }
                }
            }
        }
        else {
            if (values.stateTypes == null) {
                return synthContext.getComponentState();
            }
            int componentState = synthContext.getComponentState();
            State[] stateTypes = values.stateTypes;
            for (int length = stateTypes.length, i = 0; i < length; n2 <<= 1, ++i) {
                if (stateTypes[i].isInState(component, componentState)) {
                    n |= n2;
                }
            }
        }
        return n;
    }
    
    private NimbusStyle.RuntimeState getNextState(NimbusStyle.RuntimeState[] array, int[] array2, int n) {
        if (array != null && array.length > 0) {
            int n2 = 0;
            int n3 = -1;
            int n4 = -1;
            if (n == 0) {
                int j = array.length - 1;
                while (j >= 0) {
                    if (array[j].state == 0) {
                        array2[0] = j;
                        return array[j];
                    }
                    --j;
                }
                array2[0] = -1;
                return null;
            }
            for (int i = ((array2 == null || array2[0] == -1) ? array.length : array2[0]) - 1; i >= 0; --i) {
                int state = array[i].state;
                if (state == 0) {
                    if (n4 == -1) {
                        n4 = i;
                    }
                }
                else if ((n & state) == state) {
                    int n5 = state - ((0xAAAAAAAA & state) >>> 1);
                    int n6 = (n5 & 0x33333333) + (n5 >>> 2 & 0x33333333);
                    int n7 = n6 + (n6 >>> 4) & 0xF0F0F0F;
                    int n8 = n7 + (n7 >>> 8);
                    int n9 = n8 + (n8 >>> 16) & 0xFF;
                    if (n9 > n2) {
                        n3 = i;
                        n2 = n9;
                    }
                }
            }
            if (n3 != -1) {
                array2[0] = n3;
                return array[n3];
            }
            if (n4 != -1) {
                array2[0] = n4;
                return array[n4];
            }
        }
        array2[0] = -1;
        return null;
    }
    
    static {
        NULL = Character.valueOf('\0');
        DEFAULT_COLOR = new ColorUIResource(Color.BLACK);
        STATE_COMPARATOR = new Comparator<NimbusStyle.RuntimeState>() {
            @Override
            public int compare(NimbusStyle.RuntimeState runtimeState, NimbusStyle.RuntimeState runtimeState2) {
                return runtimeState.state - runtimeState2.state;
            }
        };
    }
    
    private final class RuntimeState implements Cloneable
    {
        int state;
        Painter backgroundPainter;
        Painter foregroundPainter;
        Painter borderPainter;
        String stateName;
        UIDefaults defaults;
        
        private RuntimeState(int state, String stateName) {
            this.defaults = new UIDefaults(10, 0.7f);
            this.state = state;
            this.stateName = stateName;
        }
        
        @Override
        public String toString() {
            return this.stateName;
        }
        
        public NimbusStyle.RuntimeState clone() {
            NimbusStyle.RuntimeState runtimeState = new NimbusStyle.RuntimeState(this.state, this.stateName);
            runtimeState.backgroundPainter = this.backgroundPainter;
            runtimeState.foregroundPainter = this.foregroundPainter;
            runtimeState.borderPainter = this.borderPainter;
            runtimeState.defaults.putAll(this.defaults);
            return runtimeState;
        }
    }
    
    private static final class Values
    {
        State[] stateTypes;
        NimbusStyle.RuntimeState[] states;
        Insets contentMargins;
        UIDefaults defaults;
        Map<NimbusStyle.CacheKey, Object> cache;
        
        private Values() {
            this.stateTypes = null;
            this.states = null;
            this.defaults = new UIDefaults(10, 0.7f);
            this.cache = new HashMap();
        }
    }
    
    private static final class CacheKey
    {
        private String key;
        private int xstate;
        
        CacheKey(Object o, int n) {
            this.init(o, n);
        }
        
        void init(Object o, int xstate) {
            this.key = o.toString();
            this.xstate = xstate;
        }
        
        @Override
        public boolean equals(Object o) {
            NimbusStyle.CacheKey cacheKey = (NimbusStyle.CacheKey)o;
            return o != null && this.xstate == cacheKey.xstate && this.key.equals(cacheKey.key);
        }
        
        @Override
        public int hashCode() {
            return 29 * (29 * 3 + this.key.hashCode()) + this.xstate;
        }
    }
}
